[**Erweiterte Optionen**](./introduction.md) > **Sprachcode** _(aktuell)_

---

#### Google

Quelle <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organisiert von GPT-4o.

| Label in Chinese | Label | `Language Code` |
| --- | --- | --- |
| Amharisch | Amharic | `am` |
| Arabisch | Arabic | `ar` |
| Baskisch | Basque | `eu` |
| Bengali | Bengali | `bn` |
| Englisch (UK) | English (UK) | `en-GB` |
| Portugiesisch (Brasilien) | Portuguese (Brazil) | `pt-BR` |
| Bulgarisch | Bulgarian | `bg` |
| Katalanisch | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| Kroatisch | Croatian | `hr` |
| Tschechisch | Czech | `cs` |
| Dänisch | Danish | `da` |
| Niederländisch | Dutch | `nl` |
| Deutsch (Deutschland) | German (Germany) | `de` |
| Estnisch | Estonian | `et` |
| 菲律宾语 | Filipino | `fil` |
| Finnisch | Finnish | `fi` |
| Französisch | French | `fr` |
| Deutsch | German | `de` |
| Griechisch | Greek | `el` |
| Gujarati | Gujarati | `gu` |
| Hebräisch | Hebrew | `iw` |
| Hindi | Hindi | `hi` |
| Ungarisch | Hungarian | `hu` |
| Isländisch | Icelandic | `is` |
| Indonesisch | Indonesian | `id` |
| Italienisch | Italian | `it` |
| Japanisch | Japanese | `ja` |
| Kannada | Kannada | `kn` |
| Koreanisch | `ko` |
| Lettisch | Latvian | `lv` |
| Litauisch | Lithuanian | `lt` |
| Malayisch | Malay | `ms` |
| Malayalam | `ml` |
| Marathi | `mr` |
| Norwegisch | Norwegian | `no` |
| Polnisch | Polish | `pl` |
| Portugiesisch (Portugal) | Portuguese (Portugal) | `pt-PT` |
| Rumänisch | Romanian | `ro` |
| Russisch | Russian | `ru` |
| Serbisch | Serbian | `sr` |
| Deutsch (Deutschland) | German (Germany) | `de-DE` |
| Slowakisch | Slovak | `sk` |
| Slowenisch | Slovenian | `sl` |
| Spanisch | Spanish | `es` |
| Swahili | Swahili | `sw` |
| Schwedisch | Swedish | `sv` |
| Tamilisch | Tamil | `ta` |
| Telugu | Telugu | `te` |
| Thailändisch | Thai | `th` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
| Türkisch | Turkish | `tr` |
| Urdu | Urdu | `ur` |
| Ukrainisch | Ukrainian | `uk` |
| Vietnamesisch | Vietnamese | `vi` |
| 威尔士语 | Welsh | `cy` |

#### DeepL

Quelle <https://developers.deepl.com/docs/resources/supported-languages>, organisiert von GPT-4o.

| Bezeichnung auf Chinesisch | Bezeichnung | `Language Code`| Unterstützung |
| --- | --- | --- | --- |
| Arabisch | Arabic | `AR` | `source`, `target` |
| Bulgarisch | Bulgarian | `BG` | `source`, `target` |
| Tschechisch | Czech | `CS` | `source`, `target` |
| Dänisch | Danish | `DA` | `source`, `target` |
| Deutsch | German | `DE` | `source`, `target` |
| Griechisch | Greek | `EL` | `source`, `target` |
| Englisch | English | `EN` | `source`, `target` |
| Englisch (UK) | English (British) | `EN-GB` | `target` |
| 德语（Deutsch） | German | `DE` | `target` |
| Spanisch | Spanish | `ES` | `source`, `target` |
| Estnisch | Estonian | `ET` | `source`, `target` |
| Finnisch | Finnish | `FI` | `source`, `target` |
| Französisch | French | `FR` | `source`, `target` |
| Ungarisch | Hungarian | `HU` | `source`, `target` |
| Indonesisch | Indonesian | `ID` | `source`, `target` |
| Italienisch | Italian | `IT` | `source`, `target` |
| Japanisch | Japanese | `JA` | `source`, `target` |
| Koreanisch | Korean | `KO` | `source`, `target` |
| Litauisch | Lithuanian | `LT` | `source`, `target` |
| Lettisch | Latvian | `LV` | `source`, `target` |
| Norwegisch Bokmål | Norwegian Bokmål | `NB` | `source`, `target` |
| Niederländisch | Dutch | `NL` | `source`, `target` |
| Polnisch | Polish | `PL` | `source`, `target` |
| Portugiesisch | Portuguese | `PT` | `source`, `target` |
| Portugiesisch (Brasilianisch) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Portugiesisch (Europäisch) | Portuguese (European) | `PT-PT` | `target` |
| Rumänisch | Romanian | `RO` | `source`, `target` |
| Russisch | Russian | `RU` | `source`, `target` |
| Slowakisch | Slovak | `SK` | `source`, `target` |
| Slowenisch | Slovenian | `SL` | `source`, `target` |
| Schwedisch | Swedish | `SV` | `source`, `target` |
| Türkisch | Turkish | `TR` | `source`, `target` |
| Ukrainisch | Ukrainian | `UK` | `source`, `target` |
| Deutsch | German | `DE` | `source`, `target` |
| Deutsch | German | `DE` | `target` |

Hier ist die übersetzte Markdown-Tabelle:

```markdown
| Chinesisch (Vereinfacht) | Chinese (Simplified) | `ZH-HANS` | `target` |
| Deutsch | German | `DE` | `target` |
```
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Ein Teil des Inhalts dieser Seite wurde von GPT übersetzt und kann Fehler enthalten.</small></h6>